@@ -51,7 +51,7 @@
         <translation>Söndürülüb</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -385,61 +385,6 @@
         <translation>Görünüş mövzusu</translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>Müasir rejim</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>Səmərəli rejim</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>Yuxarı</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>Aşağı</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>Sol</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>Sağ</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>Görünsün</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>Gizlədilsin</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>Ağıllı gizlətmə</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>Rejim</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>Yerləşmə</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Vəziyyəti</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation>Dok panel ayarları</translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
@@ -494,7 +439,7 @@
     </message>
     <message>
         <source>Balance Performance</source>
-        <translation type="unfinished"/>
+        <translation>Yaxşı Yükləmə</translation>
     </message>
 </context>
 <context>
