@@ -37,7 +37,7 @@
     <name>BluetoothAdapterItem</name>
     <message>
         <source>My Devices</source>
-        <translation type="unfinished"/>
+        <translation>Meine Geräte</translation>
     </message>
 </context>
 <context>
@@ -51,8 +51,8 @@
         <translation>Ausgeschaltet</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
-        <translation type="unfinished"/>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
+        <translation>Zuerst den [Flugmodus](#) ausschalten, wenn Sie sich über Bluetooth verbinden wollen</translation>
     </message>
 </context>
 <context>
@@ -254,7 +254,7 @@
     <name>DeviceControlWidget</name>
     <message>
         <source>Other Devices</source>
-        <translation type="unfinished"/>
+        <translation>Andere Geräte</translation>
     </message>
 </context>
 <context>
@@ -307,59 +307,59 @@
     </message>
     <message>
         <source>Display settings</source>
-        <translation type="unfinished"/>
+        <translation>Anzeige-Einstellungen</translation>
     </message>
     <message>
         <source>Eye comfort</source>
-        <translation type="unfinished"/>
+        <translation>Augenschonung</translation>
     </message>
     <message>
         <source>Theme</source>
-        <translation type="unfinished"/>
+        <translation>Design</translation>
     </message>
     <message>
         <source>On</source>
-        <translation type="unfinished"/>
+        <translation>An</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"/>
+        <translation>Aus</translation>
     </message>
     <message>
         <source>Light</source>
-        <translation type="unfinished"/>
+        <translation>Hell</translation>
     </message>
     <message>
         <source>Dark</source>
-        <translation type="unfinished"/>
+        <translation>Dunkel</translation>
     </message>
     <message>
         <source>Auto</source>
-        <translation type="unfinished"/>
+        <translation>Auto</translation>
     </message>
     <message>
         <source>Disable eye comfort</source>
-        <translation type="unfinished"/>
+        <translation>Augenschonen abwählen</translation>
     </message>
     <message>
         <source>Enable eye comfort</source>
-        <translation type="unfinished"/>
+        <translation>Augenschonen</translation>
     </message>
     <message>
         <source>Display Settings</source>
-        <translation type="unfinished"/>
+        <translation>Anzeige-Einstellungen</translation>
     </message>
     <message>
         <source>Theme: Light</source>
-        <translation type="unfinished"/>
+        <translation>Design: hell</translation>
     </message>
     <message>
         <source>Theme: Dark</source>
-        <translation type="unfinished"/>
+        <translation>Design: Dunkel</translation>
     </message>
     <message>
         <source>Theme: Auto</source>
-        <translation type="unfinished"/>
+        <translation>Design: Auto</translation>
     </message>
     <message>
         <source>Visual effect</source>
@@ -370,74 +370,19 @@
     <name>EyeComfortmodeApplet</name>
     <message>
         <source>Light</source>
-        <translation type="unfinished"/>
+        <translation>Hell</translation>
     </message>
     <message>
         <source>Dark</source>
-        <translation type="unfinished"/>
+        <translation>Dunkel</translation>
     </message>
     <message>
         <source>Auto</source>
-        <translation type="unfinished"/>
+        <translation>Auto</translation>
     </message>
     <message>
         <source>Theme</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>Design-Modus</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>Effizienzmodus</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>Oben</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>nten</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>Links</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>Rechts</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>Angezeigt lassen</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>Immer ausblenden</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>Schlaues Ausblenden</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>Modus</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>Ort</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Status</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation>Dock-Einstellungen</translation>
+        <translation>Design</translation>
     </message>
 </context>
 <context>
@@ -452,7 +397,7 @@
     </message>
     <message>
         <source>Notifications</source>
-        <translation>Mitteilungen</translation>
+        <translation>Benachrichtigungen</translation>
     </message>
     <message>
         <source>Turn off DND mode</source>
@@ -464,7 +409,7 @@
     </message>
     <message>
         <source>Notification</source>
-        <translation>Mitteilung</translation>
+        <translation>Benachrichtigung</translation>
     </message>
 </context>
 <context>
@@ -494,7 +439,7 @@
     </message>
     <message>
         <source>Balance Performance</source>
-        <translation type="unfinished"/>
+        <translation>Ausgeglichene Leistung</translation>
     </message>
 </context>
 <context>
@@ -625,7 +570,7 @@
     </message>
     <message>
         <source>Suspend</source>
-        <translation>Bereitschaftszustand</translation>
+        <translation>Bereitschaft</translation>
     </message>
     <message>
         <source>Hibernate</source>
@@ -661,7 +606,7 @@
     </message>
     <message>
         <source>Switch user</source>
-        <translation type="unfinished"/>
+        <translation>Benutzer wechseln</translation>
     </message>
 </context>
 <context>
