@@ -53,7 +53,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -387,61 +387,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>حالت فشن</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>حالت کارآمد</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>بالا</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>پایین</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>چپ</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>راست</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>نمایش داده شود</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>مخفی نگاه داشتن</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>مخفی سازی هوشمند</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>حالت</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>مکان</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>وضعیت </translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
