@@ -51,7 +51,7 @@
         <translation>كۆكچىشنى تاقاش</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -385,61 +385,6 @@
         <translation>ئۇسلۇب</translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>مودا ھالەت</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>يۇقىرى ئۈنۈملۈك ھالەت</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>ئۈستى</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>ئاستى تەرەپ</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>سول تەرەپ</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>ئوڭ تەرەپ</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>كۆرسىتىش</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>يوشۇرۇش</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>ئەقلىي يوشۇرۇش</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>ھالىتى</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>ئورنى</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>ھالىتى </translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation>ۋەزىپە ئىستونى تەڭشىكى</translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
