@@ -51,7 +51,7 @@
         <translation>藍牙關閉</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -385,61 +385,6 @@
         <translation>主題</translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>時尚模式</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>高效模式</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>上</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>下</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>左</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>右</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>一直顯示</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>一直隱藏</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>智慧隱藏</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>模式</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>位置</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>狀態</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation>任務欄設定</translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
